@@ -1,24 +1,24 @@
 #!/usr/local/bin/python2.7
 #******************************************************************************
-#  $Id: gcps2vec.py 28389 2015-01-30 19:26:09Z rouault $
-# 
+#  $Id: gcps2vec.py 33790 2016-03-26 12:42:12Z goatbar $
+#
 #  Project:  GDAL
 #  Purpose:  Convert GCPs to a point layer.
 #  Author:   Frank Warmerdam, warmerdam@pobox.com
-# 
+#
 #******************************************************************************
 #  Copyright (c) 2005, Frank Warmerdam <warmerdam@pobox.com>
-# 
+#
 #  Permission is hereby granted, free of charge, to any person obtaining a
 #  copy of this software and associated documentation files (the "Software"),
 #  to deal in the Software without restriction, including without limitation
 #  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 #  and/or sell copies of the Software, and to permit persons to whom the
 #  Software is furnished to do so, subject to the following conditions:
-# 
+#
 #  The above copyright notice and this permission notice shall be included
 #  in all copies or substantial portions of the Software.
-# 
+#
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 #  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 #  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -28,17 +28,13 @@
 #  DEALINGS IN THE SOFTWARE.
 #******************************************************************************
 
-try:
-    from osgeo import gdal
-    from osgeo import ogr
-    from osgeo import osr
-except ImportError:
-    import gdal
-    import ogr
-    import osr
-
 import sys
 
+from osgeo import gdal
+from osgeo import ogr
+from osgeo import osr
+
+
 def Usage():
     print('Usage: gcps2vec.py [-of <ogr_drivername>] [-p] <raster_file> <vector_file>')
     sys.exit(1)
@@ -84,7 +80,7 @@ if out_file is None:
     Usage()
 
 # ----------------------------------------------------------------------------
-# Open input file, and fetch GCPs. 
+# Open input file, and fetch GCPs.
 # ----------------------------------------------------------------------------
 ds = gdal.Open( in_file )
 if ds is None:
@@ -147,7 +143,7 @@ fd = ogr.FieldDefn( 'Info', ogr.OFTString )
 layer.CreateField( fd )
 
 # ----------------------------------------------------------------------------
-# Write GCPs. 
+# Write GCPs.
 # ----------------------------------------------------------------------------
 
 for gcp in gcps:
@@ -165,7 +161,7 @@ for gcp in gcps:
         feat.SetField( 'Y',  gcp.GCPY )
         feat.SetField( 'Z',  gcp.GCPZ )
         geom.SetPoint( 0, gcp.GCPPixel, gcp.GCPLine )
-        
+
     feat.SetField( 'Id',    gcp.Id )
     feat.SetField( 'Info',  gcp.Info )
 
@@ -174,5 +170,3 @@ for gcp in gcps:
 
 feat = None
 ds.Destroy()
-
-
