@@ -1,25 +1,25 @@
 #!/usr/local/bin/python2.7
 #******************************************************************************
-#  $Id: gdal_fillnodata.py 28389 2015-01-30 19:26:09Z rouault $
-# 
+#  $Id: gdal_fillnodata.py 33790 2016-03-26 12:42:12Z goatbar $
+#
 #  Project:  GDAL Python Interface
 #  Purpose:  Application for filling nodata areas in a raster by interpolation
 #  Author:   Frank Warmerdam, warmerdam@pobox.com
-# 
+#
 #******************************************************************************
 #  Copyright (c) 2008, Frank Warmerdam
 #  Copyright (c) 2009-2011, Even Rouault <even dot rouault at mines-paris dot org>
-# 
+#
 #  Permission is hereby granted, free of charge, to any person obtaining a
 #  copy of this software and associated documentation files (the "Software"),
 #  to deal in the Software without restriction, including without limitation
 #  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 #  and/or sell copies of the Software, and to permit persons to whom the
 #  Software is furnished to do so, subject to the following conditions:
-# 
+#
 #  The above copyright notice and this permission notice shall be included
 #  in all copies or substantial portions of the Software.
-# 
+#
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 #  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 #  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -29,19 +29,16 @@
 #  DEALINGS IN THE SOFTWARE.
 #******************************************************************************
 
-try:
-    from osgeo import gdal
-except ImportError:
-    import gdal
-
 import sys
 
+from osgeo import gdal
+
 def CopyBand( srcband, dstband ):
     for line in range(srcband.YSize):
         line_data = srcband.ReadRaster( 0, line, srcband.XSize, 1 )
         dstband.WriteRaster( 0, line, srcband.XSize, 1, line_data,
                              buf_type = srcband.DataType )
-        
+
 def Usage():
     print("""
 gdal_fillnodata [-q] [-md max_distance] [-si smooth_iterations]
@@ -49,7 +46,7 @@ gdal_fillnodata [-q] [-md max_distance] [-si smooth_iterations]
                 srcfile [-nomask] [-mask filename] [-of format] [-co name=value]* [dstfile]
 """)
     sys.exit(1)
-    
+
 # =============================================================================
 # 	Mainline
 # =============================================================================
@@ -87,33 +84,33 @@ while i < len(argv):
 
     elif arg == '-q' or arg == '-quiet':
         quiet_flag = 1
-        
+
     elif arg == '-si':
         i = i + 1
         smoothing_iterations = int(argv[i])
-        
+
     elif arg == '-b':
         i = i + 1
         src_band = int(argv[i])
-        
+
     elif arg == '-md':
         i = i + 1
         max_distance = float(argv[i])
-        
+
     elif arg == '-nomask':
         mask = 'none'
-        
+
     elif arg == '-mask':
         i = i + 1
         mask = argv[i]
-        
+
     elif arg == '-mask':
         i = i + 1
         mask = argv[i]
-        
+
     elif arg[:2] == '-h':
         Usage()
-        
+
     elif src_filename is None:
         src_filename = argv[i]
 
@@ -127,7 +124,7 @@ while i < len(argv):
 
 if src_filename is None:
     Usage()
-    
+
 # =============================================================================
 # 	Verify we have next gen bindings with the sievefilter method.
 # =============================================================================
@@ -148,7 +145,7 @@ if dst_filename is None:
     src_ds = gdal.Open( src_filename, gdal.GA_Update )
 else:
     src_ds = gdal.Open( src_filename, gdal.GA_ReadOnly )
-    
+
 if src_ds is None:
     print('Unable to open %s' % src_filename)
     sys.exit(1)
@@ -176,7 +173,7 @@ if dst_filename is not None:
     if wkt != '':
         dst_ds.SetProjection( wkt )
     dst_ds.SetGeoTransform( src_ds.GetGeoTransform() )
-    
+
     dstband = dst_ds.GetRasterBand(1)
     CopyBand( srcband, dstband )
     ndv = srcband.GetNoDataValue()
@@ -194,7 +191,7 @@ if quiet_flag:
     prog_func = None
 else:
     prog_func = gdal.TermProgress
-    
+
 result = gdal.FillNodata( dstband, maskband,
                           max_distance, smoothing_iterations, options,
                           callback = prog_func )
@@ -203,4 +200,3 @@ result = gdal.FillNodata( dstband, maskband,
 src_ds = None
 dst_ds = None
 mask_ds = None
-
