@@ -1,24 +1,24 @@
 #!/usr/local/bin/python2.7
 #******************************************************************************
-#  $Id: gdalident.py 24064 2012-03-04 00:34:19Z warmerdam $
-# 
+#  $Id: gdalident.py 32555 2015-12-30 19:26:44Z goatbar $
+#
 #  Project:  GDAL
 #  Purpose:  Application to identify files by format.
 #  Author:   Frank Warmerdam, warmerdam@pobox.com
-# 
+#
 #******************************************************************************
 #  Copyright (c) 2007, Frank Warmerdam <warmerdam@pobox.com>
-# 
+#
 #  Permission is hereby granted, free of charge, to any person obtaining a
 #  copy of this software and associated documentation files (the "Software"),
 #  to deal in the Software without restriction, including without limitation
 #  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 #  and/or sell copies of the Software, and to permit persons to whom the
 #  Software is furnished to do so, subject to the following conditions:
-# 
+#
 #  The above copyright notice and this permission notice shall be included
 #  in all copies or substantial portions of the Software.
-# 
+#
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 #  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 #  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -28,14 +28,13 @@
 #  DEALINGS IN THE SOFTWARE.
 #******************************************************************************
 #
-try:
-    from osgeo import gdal
-except ImportError:
-    import gdal
 
-import sys
-import stat
 import os
+import stat
+import sys
+
+from osgeo import gdal
+
 
 # =============================================================================
 # 	Usage()
@@ -58,7 +57,7 @@ def ProcessTarget( target, recursive, report_failure, filelist = None ):
     if driver is not None:
         print('%s: %s' % (target, driver.ShortName))
     elif report_failure:
-        print('%s: unrecognised' % target)
+        print('%s: unrecognized' % target)
 
     if recursive and driver is None:
         try:
@@ -71,7 +70,7 @@ def ProcessTarget( target, recursive, report_failure, filelist = None ):
             for item in subfilelist:
                 subtarget = os.path.join(target,item)
                 ProcessTarget( subtarget, 1, report_failure, subfilelist )
-            
+
 # =============================================================================
 # 	Mainline
 # =============================================================================
